#
# spec file for package solarus-quest-editor
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           solarus-quest-editor
Version:        1.6.2
Release:        2.1
Summary:        GUI to edit quests for the Solarus engine
License:        GPL-3.0-or-later AND CC-BY-SA-3.0
Group:          Productivity/Graphics/Other
URL:            https://www.solarus-games.org/
Source:         https://gitlab.com/solarus-games/solarus-quest-editor/-/archive/v%{version}/%{name}-v%{version}.tar.bz2
# PATCH-FIX-UPSTREAM
Patch0:         0001-Use-pkg-config-to-get-more-search-paths.patch
BuildRequires:  cmake >= 2.8.11
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  glm-devel
BuildRequires:  hicolor-icon-theme
BuildRequires:  physfs-devel
BuildRequires:  solarus-devel >= 1.6.0
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Help)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(SDL2_image)
BuildRequires:  pkgconfig(SDL2_ttf)
BuildRequires:  pkgconfig(libmodplug)
BuildRequires:  pkgconfig(luajit)
BuildRequires:  pkgconfig(openal)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(vorbis)
Requires:       %{name}-assets = %{version}

%description
Solarus Quest Editor is a graphical user interface to create and
modify quests for the Solarus engine.

%package assets
Summary:        Assets for the Solarus Quest Editor
Group:          Productivity/Graphics/Other
BuildArch:      noarch

%description assets
This package contains assets for the Solarus Quest Editor.

%lang_package

%prep
%setup -q -n %{name}-v%{version}
%patch0 -p1

%build
%cmake
%cmake_build

%install
%cmake_install
%fdupes %{buildroot}%{_prefix}
%find_lang solarus_editor --with-qt

%files
%license license.txt license_gpl.txt
%doc readme.md changelog.txt
%{_bindir}/%{name}
%dir %{_datadir}/%{name}
%dir %{_datadir}/icons/hicolor/20x20
%dir %{_datadir}/icons/hicolor/20x20/apps
%dir %{_datadir}/icons/hicolor/40x40
%dir %{_datadir}/icons/hicolor/40x40/apps
%{_datadir}/icons/hicolor/*/apps/%{name}*
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.png

%files assets
%{_datadir}/%{name}/assets

%files lang -f solarus_editor.lang
%dir %{_datadir}/%{name}/translations

%changelog
* Tue Mar 24 2020 Christophe Giboudeaux <christophe@krop.fr>
- Add patch to find moonjit:
  * 0001-Use-pkg-config-to-get-more-search-paths.patch
* Sat Aug 17 2019 Antoine Belvire <antoine.belvire@opensuse.org>
- Update to version 1.6.2:
  * Fix crash when closing tileset views (#467).
  * Fix broken enemies in the initial quest (#466).
  * Automatically install translation files.
  * Update French translation.
- Remove solarus-quest-editor-v1.6.1-install-translations.patch:
  Merged upstream.
* Mon Aug 12 2019 antoine.belvire@opensuse.org
- Install translations:
  * Add solarus-quest-editor-v1.6.1-install-translations.patch
    which allows installation of translation files with CMake.
  * Add lang subpackage.
- Split assets into a noarch subpackage.
- Drop obsolete build dependency on update-desktop-files.
* Sat Aug 10 2019 antoine.belvire@opensuse.org
- Update to version 1.6.1:
  * Allow to build a quest package (#431).
  * Map editor: allow teletransporters to have any size multiple of
    8 pixels.
  * Map editor: improve performance of deleting multiple entities.
  * Map editor: fix performance of changing entities layer (#454).
  * Map editor: fix wrong selections after undoing changing layers.
  * Tileset editor: fix performance of removing multiple patterns
    (#456).
  * Sprite editor: fix persisting error message about missing
    source image (#451).
  * Dialogs editor: fix line wrapping.
  * Initial quest: remove proprietary file added by mistake.
  * Add Force Software Rendering option to 'Running' section.
* Mon Dec 24 2018 antoine.belvire@opensuse.org
- Update to version 1.6.0:
  * Allow to import files from other quests.
  * Quest tree:
    + Show all .png and .dat files.
    + Show all language files, map files and tileset files.
    + Allow to set the author and license information of files.
    + Automatically select the currently open file.
    + Allow to update sprites when renaming a .png file.
    + Allow to open folders with the system explorer.
    + Allow to select multiple files.
    + Allow to delete multiple files and directories.
  * Allow to view PNG files.
  * Map/tileset editor: allow to generate borders automatically
    (autotiles).
  * Map editor:
    + Add support of custom properties for entities by Maxs.
    + Allow to use multiple tilesets in the same map.
    + Allow to change the pattern of existing tiles.
    + Allow to change the pattern of all similar tiles at once.
    + Allow to change the origin of custom entities.
    + Allow to initially enable or disable any entity.
    + Allow to export the view as a PNG file.
    + Allow to lock layers.
    + Show the layer under the cursor in the status bar.
    + Add shortcuts to show/hide negative layers too.
    + Keep the selection after adding entities with ctrl or shift.
    + Add a shortcut to open the tileset by Akadream.
    + Don't reload the tileset if it is already open elsewhere.
    + Automatically reload the tileset when it has changed.
  * Tileset editor:
    + Allow to change the frame number and delay of patterns.
    + Allow to duplicate tile patterns.
    + Allow to move several patterns at once.
  * Sprite editor:
    + Allow to reorder directions by Maxs.
    + Allow to change the frame number graphically by Maxs.
    + The default origin is now 8,13 as usual in Solarus.
    + Fix precision issues when creating or moving directions.
    + Fix scrollbars reset when adding directions by Maxs.
    + Show the line and column number.
    + Allow a replace option to the find dialog by Akadream.
  * Allow to select map/tileset/sprite/etc. ids to copy-paste them.
  * Lua console: provide variables game, map, entities and function
    tp.
  * Clear the console when a quest is started.
  * Fix resource declaration not updated when renaming a directory.
  * Fix crash when opening quest in non-UTF8 filesystems.
  * Fix error message when opening a read-only quest.
  * Fix memory not released when closing an editor.
  * Initial quest: add some shaders.
  * Text editor: allow to set an external editor to be used instead
    of the built-in one.
- Update build dependencies:
  * Add glm-devel: Was previously embedded in upstream tarball.
  * Add pkgconfig(Qt5Concurrent): New dependency.
- Remove solarus-quest-editor-1.5.3-fix-compilation.patch: Fixed
  upstream.
* Thu Nov  8 2018 antoine.belvire@opensuse.org
- Add solarus-quest-editor-1.5.3-fix-compilation.patch: Fix build
  on Tumbleweed (boo#1115055).
- Update source URL: Project has migrated to GitLab.
- Minor spec file cleanup.
* Wed Apr 11 2018 antoine.belvire@opensuse.org
- Update to version 1.5.3:
  * Initial quest: add enemy killed animation from Diarandor.
  * Initial quest: fix the source image of the bomb sprite.
  * Initial quest: make musics loop without separate file for their
    intro.
  * Initial quest: add sounds from the Solarus Free Resource Pack.
  * Initial quest: play a sound with the Solarus logo.
  * Fix error message when converting from older formats to 1.5.2.
- Remove upstreamed patch:
  * desktop-icons.patch.
  * luajit-5_1-2.1.patch.
- Use %%license instead of %%doc for license files (boo#1082318).
* Thu Jan 26 2017 jengelh@inai.de
- Trim filler words
* Wed Jan 25 2017 mailaender@opensuse.org
- initial packaging of version 1.5.2
- Added luajit-5_1-2.1.patch
- Added desktop-icons.patch
